@@ -21,7 +21,7 @@ using namespace std;
 
 PYBIND11_MODULE(ctextlib, m)
 {
-    py::class_<CTextA> (m, "CTextA")
+    py::class_<CTextA> (m, "Text")
         // constructors
         .def(py::init<>())
         .def(py::init<const char*>())
@@ -201,7 +201,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("writeFile", &CTextA::writeFile<char>, "write string to a text file with the given encoding", py::arg("path"), py::arg("encoding") = 1, py::arg("asHex") = false)
         ;
         
-    py::class_<CTextU> (m, "CTextU")
+    py::class_<CTextU> (m, "TextU")
         // constructors
         .def(py::init<>())
         .def(py::init<const wchar_t*>())
@@ -231,7 +231,6 @@ PYBIND11_MODULE(ctextlib, m)
         .def("collectBlocks", [](CTextU& s, const wchar_t* sepBegin, const wchar_t* sepEnd, bool all)->vector<wstring> {  vector<wstring> res;  s.collectBlocks(res, sepBegin, sepEnd, all); return res; }, "collect blocks", py::arg("sepBegin"), py::arg("sepEnd"), py::arg("all") = true)
         .def("collectLines", [](CTextU& s, const wchar_t* sep)->vector<wstring> {  vector<wstring> res;  s.collectLines(res, false, sep); return res; }, "fills a list with the collected lines", py::arg("sep") = CTextU::SeparatorsLine)
         .def("checkBalance", &CTextU::checkBalance, "checks if the blocks defined with the given separators are balanced")
-        .def("convertToHex", &CTextU::toHex, "convert string to hex values", py::arg("sep") = CTextU::SPACE)
         .def("contain", (bool (CTextU::*)(const wchar_t* s, bool bCase) const) &CTextU::contain, "returns true if our string contains another string  ", py::arg("str"), py::arg("case") = true)
         .def("contain", [](CTextU& s, const vector<wstring>& list, bool bCase)->bool { return s.containAny(list, bCase, true); }, "returns true if contains any of the provided strings", py::arg("list"), py::arg("case") = true)
         .def("containAny", (bool (CTextU::*)(const wchar_t* s, bool bCase) const) &CTextU::containAny, "returns true if our string contains any of the characters in the list", py::arg("str"), py::arg("case") = true)
@@ -361,6 +360,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("split", [](CTextU& s, const wchar_t* sep = CTextU::Separators)->vector<wstring> { vector<wstring> res;  s.split(res, false, sep); return res; }, "fills the STL container with the collected substrings", py::arg("sep") = CTextU::Separators)
         .def("str", (const wchar_t* (CTextU::*)(size_t pos) const) &CTextU::str, "return text buffer", py::arg("pos") = 0)
         .def("toBinary", &CTextU::toBinary, "if the string contains a binary number, convert it  ")
+        .def("toHex", &CTextU::toHex, "convert string to hex values separated by the given separator", py::arg("sep") = CTextU::SPACE)
         .def("toHexNumber", &CTextU::toHexNumber, "if the string contains a hex number, convert it , 1E --> 30")
         .def("toDouble", &CTextU::toDouble)
         .def("toInteger", &CTextU::toInteger)
